@@ -1,3 +1,5 @@
+import time
+
 import napari
 from pandas import DataFrame
 from qtpy.QtCore import QTimer
@@ -21,9 +23,14 @@ class TableWidget(QWidget):
         self._viewer = viewer
 
         self._view = QTableWidget()
-        self.set_content(layer.properties)
+        self._view.setEditTriggers(QTableWidget.EditTrigger.NoEditTriggers)
+        if hasattr(layer, "properties"):
+            self.set_content(layer.properties)
+        else:
+            self.set_content({})
 
         self._view.clicked.connect(self._clicked_table)
+        self._view.horizontalHeader().sectionDoubleClicked.connect(self._double_clicked_table)
         layer.mouse_drag_callbacks.append(self._clicked_labels)
 
         copy_button = QPushButton("Copy to clipboard")
@@ -58,6 +65,44 @@ class TableWidget(QWidget):
                     current_step[-4] = frame
                     self._viewer.dims.current_step = current_step
 
+    def _double_clicked_table(self):
+        if "label" in self._table.keys():
+            selected_column = list(self._table.keys())[self._view.currentColumn()]
+            print("Selected column", selected_column)
+            if selected_column is not None:
+                if isinstance(self._layer, napari.layers.Labels):
+                    from ._parametric_images import visualize_measurement_on_labels
+                    new_layer = self._viewer.add_image(visualize_measurement_on_labels(self._layer, selected_column, self._viewer),
+                                           name=selected_column + " in " + self._layer.name)
+                    new_layer.contrast_limits = [np.min(self._table[selected_column]), np.max(self._table[selected_column])]
+                    new_layer.colormap = "jet"
+                elif isinstance(self._layer, napari.layers.Points):
+                    features = self._layer.features
+                    new_layer = self._viewer.add_points(self._layer.data,
+                                                        features=features,
+                                                        face_color=selected_column,
+                                                        face_colormap="jet",
+                                                        size=self._layer.size,
+                                                        name=selected_column + " in " + self._layer.name
+                                                        )
+                    new_layer.contrast_limits = [np.min(self._table[selected_column]), np.max(self._table[selected_column])]
+
+        if "vertex_index" in self._table.keys():
+            selected_column = list(self._table.keys())[self._view.currentColumn()]
+            print("Selected column (T)", selected_column)
+            if selected_column is not None and isinstance(self._layer, napari.layers.Surface):
+                values = np.asarray(self._table[selected_column])
+                data = self._layer.data
+                data = [np.asarray(data[0]).copy(), np.asarray(data[1]).copy(), values]
+
+                new_layer = self._viewer.add_surface(data,
+                    name=selected_column + " in " + self._layer.name)
+                new_layer.contrast_limits = [np.min(self._table[selected_column]), np.max(self._table[selected_column])]
+                if "annotation" in selected_column or "CLUSTER_ID" in selected_column:
+                    new_layer.colormap = "hsv"
+                else:
+                    new_layer.colormap = "jet"
+
     def _after_labels_clicked(self):
         if "label" in self._table.keys() and hasattr(self._layer, "selected_label"):
             row = self._view.currentRow()
@@ -211,11 +256,17 @@ def get_table(labels_layer: napari.layers.Layer, viewer:napari.Viewer) -> TableW
     Searches inside a viewer for a given table and returns it. If it cannot find it,
     it will return None.
     """
-    for widget in list(viewer.window._dock_widgets.values()):
-        potential_table_widget = widget.widget()
-        if isinstance(potential_table_widget, TableWidget):
-            if potential_table_widget._layer is labels_layer:
-                return potential_table_widget
+    import warnings
+    # see: https://github.com/napari/napari/issues/3944
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+
+        for widget in list(viewer.window._dock_widgets.values()):
+            potential_table_widget = widget.widget()
+            if isinstance(potential_table_widget, TableWidget):
+                if potential_table_widget._layer is labels_layer:
+                    return potential_table_widget
+
     return None
 
 def _determine_frame_column(table):
