@@ -26,7 +26,7 @@ def test_regionprops(make_napari_viewer):
 
     # analyze everything we can
     from napari_skimage_regionprops import regionprops
-    regionprops(image_layer, labels_layer, viewer, True, True, True, True, True, True)
+    regionprops(image_layer, labels_layer, True, True, True, True, True, True, viewer)
 
     # there is now a table in the viewer
     assert len(viewer.window._dock_widgets) == num_dw + 1
@@ -55,8 +55,8 @@ def test_regionprops(make_napari_viewer):
 
     # generate a parametric image
     from napari_skimage_regionprops import visualize_measurement_on_labels
-    layer = visualize_measurement_on_labels(labels_layer, "area")
-    assert layer is not None
+    result = visualize_measurement_on_labels(labels_layer, "area", viewer)
+    assert result is not None
 
     reference = np.asarray([
         [0, 0, 0, 0, 0, 0, 0],
@@ -67,9 +67,9 @@ def test_regionprops(make_napari_viewer):
         [0, 0, 6, 6, 6, 0, 0],
         [0, 0, 6, 6, 6, 0, 1],
     ])
-    print("layer.data: ", layer.data)
+    print("result: ", result)
     print("reference: ", np.asarray(reference))
-    assert np.array_equal(layer.data, reference)
+    assert np.array_equal(result, reference)
 
     # replace table
     from napari_skimage_regionprops import add_table
@@ -81,6 +81,14 @@ def test_regionprops(make_napari_viewer):
     table_widget.append_content(fake_area)
     assert 'Double area' in table_widget.get_content().keys()
 
+    # save table to disk
+    import pandas as pd
+    pd.DataFrame(labels_layer.properties).to_csv("test.csv")
+    from napari_skimage_regionprops import load_csv
+    load_csv("test.csv", labels_layer)
+    load_csv("test.csv", labels_layer, viewer)
+
+
     # empty table
     table_widget.set_content(None)
     table_widget.update_content()
@@ -141,7 +149,7 @@ def test_regionprops_without_moments(make_napari_viewer):
 
     # analyze everything we can
     from napari_skimage_regionprops import regionprops
-    regionprops(image_layer, labels_layer, viewer, True, True, True, True, True, False)
+    regionprops(image_layer, labels_layer, size=True, intensity=True, perimeter=True, shape=True, position=True, moments=False, napari_viewer=viewer)
 
 def test_3d_2d(make_napari_viewer):
 
@@ -172,7 +180,8 @@ def test_3d_2d(make_napari_viewer):
 
     # analyze everything we can
     from napari_skimage_regionprops import regionprops
-    regionprops(image_layer, labels_layer, viewer, True, True, True, True, True, True)
+    regionprops(image_layer, labels_layer, size=True, intensity=True, perimeter=True, shape=True, position=True,
+                moments=True, napari_viewer=viewer)
 
     # there is now a table in the viewer
     assert len(viewer.window._dock_widgets) == num_dw + 1
@@ -214,7 +223,8 @@ def test_3d(make_napari_viewer):
 
     # analyze everything we can
     from napari_skimage_regionprops import regionprops
-    regionprops(image_layer, labels_layer, viewer, True, True, True, True, True, True)
+    regionprops(image_layer, labels_layer, size=True, intensity=True, perimeter=True, shape=True, position=True,
+                moments=True, napari_viewer=viewer)
 
     # there is now a table in the viewer
     assert len(viewer.window._dock_widgets) == num_dw + 1
@@ -227,6 +237,52 @@ def test_3d(make_napari_viewer):
     print(area_measurements)
     assert np.array_equal([27, 18, 18, 12], area_measurements)
 
+
+def test_3d_dask(make_napari_viewer):
+
+    viewer = make_napari_viewer()
+    import dask.array as da
+
+    num_dw = len(viewer.window._dock_widgets)
+
+
+    import numpy as np
+
+    image = np.asarray([
+        [0, 0, 0, 0, 0, 0, 0],
+        [1, 1, 1, 0, 0, 2, 2],
+        [1, 1, 1, 0, 0, 2, 2],
+        [1, 1, 1, 0, 0, 2, 2],
+        [0, 0, 0, 0, 0, 0, 0],
+        [0, 0, 3, 3, 3, 4, 4],
+        [0, 0, 3, 3, 3, 4, 4],
+    ]).astype(float)
+
+    # make a 3D dataset
+    image = da.asarray(np.asarray([image, image, image]))
+    labels_image = da.asarray(image.astype(int))
+
+    image_layer = viewer.add_image(image)
+    labels_layer = viewer.add_labels(labels_image)
+
+    # analyze everything we can
+    from napari_skimage_regionprops import regionprops
+    regionprops(image_layer, labels_layer, size=True, intensity=True, perimeter=True, shape=True, position=True,
+                moments=True, napari_viewer=viewer)
+
+    # there is now a table in the viewer
+    assert len(viewer.window._dock_widgets) == num_dw + 1
+
+    from napari_skimage_regionprops import get_table
+    table_widget = get_table(labels_layer, viewer)
+    assert table_widget is not None
+
+    area_measurements = table_widget.get_content()['area']
+    print(area_measurements)
+    assert np.array_equal([27, 18, 18, 12], area_measurements)
+
+
+
 def test_4d_3d(make_napari_viewer):
 
     viewer = make_napari_viewer()
@@ -259,7 +315,8 @@ def test_4d_3d(make_napari_viewer):
 
     # analyze everything we can
     from napari_skimage_regionprops import regionprops
-    regionprops(image_layer, labels_layer, viewer, True, True, True, True, True, True)
+    regionprops(image_layer, labels_layer, size=True, intensity=True, perimeter=True, shape=True, position=True,
+                moments=True, napari_viewer=viewer)
 
     # there is now a table in the viewer
     assert len(viewer.window._dock_widgets) == num_dw + 1
@@ -297,3 +354,46 @@ def test_napari_api():
 def test_napari_api2():
     from napari_skimage_regionprops._utilities import napari_experimental_provide_function
     napari_experimental_provide_function()
+
+def test_shape_descriptors():
+    import numpy as np
+    labels = np.asarray([
+        [0, 0, 0, 0, 0, 0, 0, 0],
+        [1, 1, 0, 2, 2, 2, 3, 3],
+        [1, 1, 0, 2, 2, 2, 3, 3],
+        [0, 0, 0, 2, 2, 2, 3, 3],
+        [0, 0, 0, 0, 0, 0, 3, 3],
+        [0, 4, 4, 4, 4, 4, 0, 0],
+        [0, 4, 4, 4, 4, 4, 0, 0],
+        [0, 0, 0, 0, 0, 0, 0, 0],
+        [5, 5, 5, 5, 5, 0, 6, 6],
+        [5, 5, 5, 5, 5, 0, 6, 6],
+        [5, 5, 5, 5, 5, 0, 6, 6],
+        [0, 0, 0, 0, 0, 0, 0, 0]
+    ])
+
+    from napari_skimage_regionprops import regionprops_table
+    table = regionprops_table(labels, labels, False, False, False, True)
+
+    print(table.keys())
+    assert "area" not in table.keys()
+    assert "perimeter" not in table.keys()
+
+    print("aspect_ratio", table['aspect_ratio'])
+    assert np.allclose(table['aspect_ratio'], [1., 1., 2.23606798, 2.82842712, 1.73205081, 1.63299316])
+
+    print("circularity", table['circularity'])
+    assert np.allclose(table['circularity'], [3.14159265, 1.76714587, 1.57079633, 1.25663706, 1.30899694, 2.0943951 ])
+
+    print("roundness", table['roundness'])
+    # Values > 1 should actually not appear, but do so in case of very small objects apparently
+    assert np.allclose(table['roundness'], [1.27323954, 1.07429587, 0.50929582, 0.39788736, 0.59683104, 0.71619724])
+
+def test_measure_points():
+    import numpy as np
+    import napari_skimage_regionprops as nsr
+
+    image = np.random.random((100, 200)) * 10
+    points = np.random.random((100, 2)) * 99
+
+    nsr.measure_points(points, image)
